require 'rails_helper'

module ConfigManager
	describe ToggleIdentityMap, :id_map => true do
		describe ".value" do
			let(:key) { 'key' }
			let(:val) { 'a value' }

			context "when id_map has been initialized" do
				before { ToggleIdentityMap.reset_id_map }

				context "when the key has not been set" do
					it "returns the value from the block" do
						ToggleIdentityMap.value(key) { val }.should == val
					end
				end

				context "after the key has been set" do
					before { ToggleIdentityMap.value(key) { val } }
					
					it "returns the value previously set" do
						ToggleIdentityMap.value(key) { 'not that value' }.should == val
					end

					it "doesn't yield to the fallback block" do
						expect {|b| ToggleIdentityMap.value(key, &b) }.not_to yield_control
					end
				end
			end
		end
	end
end
